// ===========================================================================
// CONTENT  : CLASS AdminMBean
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 06/05/2012
// HISTORY  :
//  06/05/2012  mdu  CREATED
//
// Copyright (c) 2012, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.admin ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import javax.management.MBeanInfo;
import javax.management.MBeanOperationInfo;
import javax.management.MBeanParameterInfo;

import org.pf.reflect.DynamicMBeanDelegator;
import org.pfsw.tools.beluga.Beluga;
import org.pfsw.tools.beluga.ldap.server.LDAPServer;

/**
 * The MBean that allows Beluga administration and monitoring via JMX.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class AdminMBean extends DynamicMBeanDelegator<AdminMBean>
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private AdminServer adminServer = null ;
  protected AdminServer getAdminServer() { return adminServer ; }
  protected void setAdminServer( AdminServer newValue ) { adminServer = newValue ; }
  
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public AdminMBean(AdminServer adminServer)
  {
    super(null) ;
    this.setReceiver(this);
    this.setAdminServer(adminServer);
    this.initMBeanInfo();
  } // AdminMBean()

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public String getVersionInformation() 
	{
		return Beluga.PROG_VERSION;
	} // getVersionInformation()
	
	// -------------------------------------------------------------------------
  
  public int getNumberOfOpenConnections() 
	{
		return this.getLDAPServer().getNumberOfOpenConnections();
	} // getNumberOfOpenConnections()
	
	// -------------------------------------------------------------------------

  public void shutdown() 
	{
		this.adminServer.shutdownLdapServer();
		this.adminServer.shutdown();
	} // shutdown()
	
	// -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected LDAPServer getLDAPServer() 
	{
		return this.adminServer.getLdapServer();
	} // getLDAPServer()
	
	// -------------------------------------------------------------------------
  
  protected void initMBeanInfo() 
	{
  	MBeanInfo info;
  	
		info = new MBeanInfo(this.getClass().getName(), "Beluga LDAP Server", null, null, this.createOperationInfo(), null);
  	this.setManagedBeanInfo(info);
	} // initMBeanInfo()
	
	// -------------------------------------------------------------------------
  
  private static MBeanOperationInfo[] createOperationInfo()
  {
    MBeanOperationInfo[] operationInfos;
    MBeanParameterInfo[] parameters;

    operationInfos = new MBeanOperationInfo[3];

		parameters = new MBeanParameterInfo[0];
		operationInfos[0] = new MBeanOperationInfo("getVersionInformation", "", parameters, "java.lang.String",	MBeanOperationInfo.INFO);

		parameters = new MBeanParameterInfo[0];
		operationInfos[1] = new MBeanOperationInfo("getNumberOfOpenConnections", "", parameters, "java.lang.Integer",	MBeanOperationInfo.INFO);

		parameters = new MBeanParameterInfo[0];
		operationInfos[2] = new MBeanOperationInfo("shutdown", "Shutdown the whole LDAP server.", parameters, "void",	MBeanOperationInfo.ACTION);
		
    return operationInfos;
  } // createOperationInfo()

  // -------------------------------------------------------------------------

} // class AdminMBean
