// ===========================================================================
// CONTENT  : CLASS AdminTask
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 08/08/2006
// HISTORY  :
//  08/08/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.admin ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pf.net.BaseTextRequestProcessor;
import org.pf.net.TextSocketConnection;
import org.pf.text.StringUtil;
import org.pfsw.tools.beluga.common.LoggerService;

/**
 * Handles all incoming administration requests.
 *
 * @author M.Duchrow
 * @version 1.0
 */
public class AdminTask extends BaseTextRequestProcessor implements AdminProtocol
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private AdminServer adminServer = null ;
  protected AdminServer getAdminServer() { return adminServer ; }
  protected void setAdminServer( AdminServer newValue ) { adminServer = newValue ; }

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  AdminTask( TextSocketConnection conn, AdminServer server )
  {
    super( conn ) ;
    this.setAdminServer( server ) ;
  } // AdminTask()

  // -------------------------------------------------------------------------

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public void processRequest( String request )
  {
  	String[] commands ;

  	this.logger().logDebug( request ) ;

  	commands = this.str().parts( request, END_OF_COMMAND ) ;
  	for (int i = 0; i < commands.length; i++ )
		{
			this.processCommand( commands[i] ) ;
		}
  } // processRequest()

  // -------------------------------------------------------------------------

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected void processCommand( String command )
	{
  	String[] strings ;

  	this.logger().logDebug( "Processing admin command: {0}", command ) ;

  	strings = this.str().parts( command, " \t" ) ;
  	if ( strings[0].equalsIgnoreCase( CMD_SHUTDOWN ) )
		{
  		this.execShutdown( strings ) ;
		}
  	else if ( strings[0].equalsIgnoreCase( CMD_SET_LOG_LEVEL ) )
		{
  		this.execSetLogLevel( strings ) ;
		}
	} // processCommand()

	// -------------------------------------------------------------------------

  protected void execShutdown( String[] cmdElements )
	{
  	this.getAdminServer().shutdownLdapServer() ;
  	this.getAdminServer().shutdown() ;
	} // execShutdown()

	// -------------------------------------------------------------------------

  protected void execSetLogLevel( String[] cmdElements )
  {
  	if ( cmdElements.length > 1 )
		{
			this.logger().changeLogLevel( cmdElements[1] ) ;
		}
  } // execSetLogLevel()

  // -------------------------------------------------------------------------

	protected LoggerService logger()
	{
		return LoggerService.getLogger() ;
	} // logger()

	// -------------------------------------------------------------------------

  protected StringUtil str()
	{
		return StringUtil.current();
	} // str()

	//-------------------------------------------------------------------------

} // class AdminTask
