// ===========================================================================
// CONTENT  : CLASS DirectoryDataFile
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 18/06/2006
// HISTORY  :
//  18/06/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.directory ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pf.file.FileLocator;

/**
 * Specifies the type and location of a file that contains directory data.
 *
 * @author M.Duchrow
 * @version 1.0
 */
public class DirectoryDataFile
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
	public static final String FILE_TYPE_LDIF				= "LDIF" ;
	public static final String FILE_TYPE_DSML				= "DSML" ;

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private FileLocator fileLocator = null ;
  public FileLocator getFileLocator() { return fileLocator ; }
  protected void setFileLocator( FileLocator newValue ) { fileLocator = newValue ; }
  
  private String fileType = FILE_TYPE_LDIF ;
  /**
   * Returns the file type. The default is LDIF.
   */
  public String getFileType() { return fileType ; }
  public void setFileType( String newValue ) { fileType = newValue ; }
  
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public DirectoryDataFile( FileLocator locator )
  {
    super() ;
    this.setFileLocator( locator ) ;
  } // DirectoryDataFile() 

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Changes the file type to be DSML
   */
  public void beDSML() 
	{
  	this.setFileType( FILE_TYPE_DSML ) ;
	} // beDSML() 
	
	// -------------------------------------------------------------------------
  
  /**
   * Changes the file type to be DSML
   */
  public void beLDIF() 
  {
  	this.setFileType( FILE_TYPE_LDIF ) ;
  } // beLDIF() 
  
  // -------------------------------------------------------------------------
  
  /**
   * Returns true if the file type is currently LDIF
   */
  public boolean isLDIF() 
	{
		return FILE_TYPE_LDIF.equals( this.getFileType() ) ;
	} // isLDIF() 
	
	// -------------------------------------------------------------------------
  
  /**
   * Returns true if the file type is currently DSML
   */
  public boolean isDSML() 
  {
  	return FILE_TYPE_DSML.equals( this.getFileType() ) ;
  } // isDSML() 
  
  // -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

} // class DirectoryDataFile 
