// ===========================================================================
// CONTENT  : ABSTRACT CLASS InterceptorChain
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 15/01/2012
// HISTORY  :
//  15/01/2012  mdu  CREATED
//
// Copyright (c) 2012, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.interceptors ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.ArrayList;
import java.util.List;

/**
 * Common abstract implementation of inspector chains.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
abstract public class InterceptorChain<TInterceptor>
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private List<TInterceptor> interceptors;
  protected List<TInterceptor> getInterceptors() { return interceptors ; }
  protected void setInterceptors( List<TInterceptor> newValue ) { interceptors = newValue ; }

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public InterceptorChain()
  {
    super() ;
    this.setInterceptors(this.createNewInspectorList());
  } // InterceptorChain() 

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Add one or more interceptors to the internal interceptor list.
   * @param interceptorsToAdd All the interceptors to be added
   */
  public void addInterceptors(TInterceptor... interceptorsToAdd) 
	{
  	if (interceptorsToAdd == null)
		{
			return;
		}
  	for (TInterceptor interceptor : interceptorsToAdd)
		{			
  		this.getInterceptors().add(interceptor);
		}
	} // addInterceptors() 
	
	// -------------------------------------------------------------------------
  
  /**
   * Remove one or more interceptors from the internal interceptor list.
   * @param interceptorsToRemove All the interceptors to be removed
   */
  public void removeInterceptors(TInterceptor... interceptorsToRemove) 
	{
  	if (interceptorsToRemove == null)
		{
			return;
		}
  	for (TInterceptor interceptor : interceptorsToRemove)
  	{			
  		this.getInterceptors().remove(interceptor);
  	}		
	} // removeInterceptors() 
	
	// -------------------------------------------------------------------------

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected List<TInterceptor> createNewInspectorList() 
	{
		return new ArrayList<TInterceptor>();
	} // createNewInspectorList() 
	
	// -------------------------------------------------------------------------
  
} // class InterceptorChain 
