// ===========================================================================
// CONTENT  : CLASS ResponseInterceptorChain
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 13/01/2012
// HISTORY  :
//  13/01/2012  mdu  CREATED
//
// Copyright (c) 2012, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.interceptors ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.tools.beluga.ldap.messages.ResponseMessage;
import org.pfsw.tools.beluga.ldap.server.IResponseInterceptor;

/**
 * The holder of all response interceptors that calls them in the defined
 * order and returns the response message received from the last interceptor.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class ResponseInterceptorChain extends InterceptorChain<IResponseInterceptor> implements IResponseInterceptor
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public ResponseInterceptorChain()
  {
    super() ;
  } // ResponseInterceptorChain() 

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public ResponseMessage handleResponse(ResponseMessage responseMessage)
  {
  	ResponseMessage result;
  	
  	result = responseMessage;
  	for (IResponseInterceptor interceptor : this.getInterceptors())
		{
			result = interceptor.handleResponse(result);
		}
  	return result;
  } // handleResponse()
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

} // class ResponseInterceptorChain 
