// ===========================================================================
// CONTENT  : ABSTRACT CLASS AbstractMessage
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 25/06/2006
// HISTORY  :
//  08/07/2004  mdu  CREATED
//	25/06/2006	mdu		added		-->	controls
//
// Copyright (c) 2004-2006, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.messages ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pf.text.StringUtil;
import org.pfsw.tools.beluga.ldap.protocol.LDAPControl;


/**
 * Abstract superclass of all LDAP messages.
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
abstract public class AbstractMessage
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
	private static final LDAPControl[] EMPTY_CONTROL_ARRAY = new LDAPControl[0] ;

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private byte[] rawData = null ;
  public byte[] getRawData() { return rawData ; }
  public void setRawData( byte[] newValue ) { rawData = newValue ; }
  
  private int messageId = -1 ;
  public int getMessageId() { return messageId ; }
  public void setMessageId( int newValue ) { messageId = newValue ; }  
  
  private LDAPControl[] controls = EMPTY_CONTROL_ARRAY ;
  public LDAPControl[] getControls() { return controls ; }
  public void setControls( LDAPControl[] newValue ) { controls = newValue ; }
  // =========================================================================
  // CLASS METHODS
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  protected AbstractMessage()
  {
    super() ;
  } // AbstractMessage() 

  // -------------------------------------------------------------------------
  
  /**
   * Initialize the new instance with default values.
   */
  protected AbstractMessage( byte[] rawData )
  {
    this() ;
    this.setRawData( rawData ) ;
  } // AbstractMessage() 

  // -------------------------------------------------------------------------
  
  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public String toString() 
	{
		StringBuffer buffer ;
		
		buffer = new StringBuffer(100) ;
		buffer.append( this.getName() ) ;
		buffer.append( "[" ) ;
		buffer.append( this.getMessageId() ) ;
		buffer.append( "]" ) ;
		//buffer.append( "(" ) ;
		this.appendParameter( buffer ) ;
		//buffer.append( ")" ) ;
		
		return buffer.toString() ;
	} // toString() 

	// -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  abstract protected String getName() ;
  
  // -------------------------------------------------------------------------
  
  protected void appendParameter( StringBuffer buffer ) 
  {
  	// Nothing to do here. Subclasses may override
  } // appendParameter()
  
  // -------------------------------------------------------------------------
 
  protected StringUtil str()
	{
		return StringUtil.current();
	} // str()

	//-------------------------------------------------------------------------
  
} // class AbstractMessage 
