// ===========================================================================
// CONTENT  : CLASS AttributeModificationDefinition
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 29/07/2006
// HISTORY  :
//  29/07/2006  mdu  CREATED
//
// Copyright (c) 2006, by M.Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.messages ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pf.directory.MultiValueAttribute;

/**
 * Specifies an operation (add, delete, replace) for a single attribute
 *
 * @author M.Duchrow
 * @version 1.0
 */
public class AttributeModificationDefinition
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
	protected static final int OPERATION_ADD				= 0 ;
	protected static final int OPERATION_DELETE			= 1 ;
	protected static final int OPERATION_REPLACE		= 2 ;

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private int operationType = OPERATION_ADD ;
  protected int getOperationType() { return operationType ; }
  protected void setOperationType( int newValue ) { operationType = newValue ; }
  
  private MultiValueAttribute attribute = null ;
  public MultiValueAttribute getAttribute() { return attribute ; }
  public void setAttribute( MultiValueAttribute newValue ) { attribute = newValue ; }
  
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public AttributeModificationDefinition( int operation )
  {
    super() ;
    this.setOperationType( operation ) ;
  } // AttributeModificationDefinition() 

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public boolean isAddOperation() 
	{
		return OPERATION_ADD == this.getOperationType() ;
	} // isAddOperation() 
	
	// -------------------------------------------------------------------------

  public boolean isDeleteOperation() 
  {
  	return OPERATION_DELETE == this.getOperationType() ;
  } // isDeleteOperation() 
  
  // -------------------------------------------------------------------------
  
  public boolean isReplaceOperation() 
  {
  	return OPERATION_REPLACE == this.getOperationType() ;
  } // isReplaceOperation() 
  
  // -------------------------------------------------------------------------
  
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

} // class AttributeModificationDefinition 
