// ===========================================================================
// CONTENT  : CLASS ProxyServer
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 17/07/2004
// HISTORY  :
//  17/07/2004  mdu  CREATED
//
// Copyright (c) 2004, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.proxy;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.io.IOException;
import java.net.Socket;

import org.pf.net.BinarySocketConnection;
import org.pfsw.tools.beluga.ldap.messages.BindRequest;
import org.pfsw.tools.beluga.ldap.messages.BindResponse;
import org.pfsw.tools.beluga.ldap.messages.SearchRequest;
import org.pfsw.tools.beluga.ldap.messages.SearchResponse;
import org.pfsw.tools.beluga.ldap.server.LDAPv3RequestProcessor;


/**
 * This request processor just forwards the request messages to another LDAP
 * server and receives the answers to hand them back to the caller.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class ProxyServer extends LDAPv3RequestProcessor
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private String serverName = "nnn.service" ;
  protected String getServerName() { return serverName ; }
  protected void setServerName( String newValue ) { serverName = newValue ; }
  
  private int port = 389 ;
  protected int getPort() { return port ; }
  protected void setPort( int newValue ) { port = newValue ; }
  
  private BinarySocketConnection connection = null ;
  protected BinarySocketConnection getConnection() { return connection ; }
  protected void setConnection( BinarySocketConnection newValue ) { connection = newValue ; }
  
  // =========================================================================
  // CLASS METHODS
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public ProxyServer()
  {
    super() ;
    this.initialize() ;
  } // ProxyServer() 

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
	public BindResponse bind( BindRequest request )
	{
		BindResponse response ;
		byte[] data ;
		
		data = this.sendReceive( request.getRawData() ) ;
		if ( data == null )
		{
			return null ;
		}
		response = new BindResponse( request ) ;
		response.setRawData( data ) ;
		return response ;
	} // bind()
	
	// -------------------------------------------------------------------------
	
	public SearchResponse[] search( SearchRequest request )
	{
		// TODO Auto-generated method stub
		return super.search( request );
	} // search()
	
	// -------------------------------------------------------------------------
	
  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
	protected byte[] sendReceive( byte[] data ) 
	{
		byte[] answer = null ;
		
		this.getConnection().writeData( data ) ;
		while ( answer == null )
		{
			try
			{
				Thread.sleep(20) ;
			}
			catch ( InterruptedException e )
			{
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			answer = this.getConnection().getData() ;
		}
		return answer ;
	} // sendReceive()

	// -------------------------------------------------------------------------

	protected void initialize()
	{
		Socket socket ;
		BinarySocketConnection conn ;
		
		try
		{
			socket = new Socket( this.getServerName(), this.getPort() ) ;
			conn = new BinarySocketConnection( socket ) ;
			this.setConnection( conn ) ;
		}
		catch (IOException e)
		{
			// TODO Replace stacktrace by logging
			e.printStackTrace() ;
		}	
	} // initialize()

	// -------------------------------------------------------------------------	
	
} // class ProxyServer 
