// ===========================================================================
// CONTENT  : INTERFACE IRequestInterceptor
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 13/01/2012
// HISTORY  :
//  13/01/2012  mdu  CREATED
//
// Copyright (c) 2012, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.server ;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.tools.beluga.ldap.messages.RequestMessage;
import org.pfsw.tools.beluga.ldap.messages.ResponseMessage;

/**
 * Used in an interceptor chain to do something with all incoming LDAP request messages. 
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
@InterceptorType("request")
public interface IRequestInterceptor
{ 
	/**
	 * Handles the given request message in some way. Usually this is something
	 * like logging, so not really consuming the message and producing a response.
	 * 
	 * @param requestMessage The completely parsed request message.
	 * @return true if processing may continue and false if request message has been 
	 * consumed by the interceptor.
	 */
	public boolean handleRequest(RequestMessage requestMessage);
	
	/**
	 * If the interceptor has consumed a request in its {@link #handleRequest(RequestMessage)}
	 * method (which then has returned false) then this method must return the response message
	 * for the consumed request. 
	 * 
	 * @return null or a response message 
	 */
	public ResponseMessage getResponse();
	
} // interface IRequestInterceptor