// ===========================================================================
// CONTENT  : CLASS LDAPv3RequestProcessor
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.2 - 29/07/2006
// HISTORY  :
//  11/07/2004  mdu  CREATED
//	27/06/2006	mdu		added		-->	delete()
//	29/07/2006	mdu		added		-->	modify()
//
// Copyright (c) 2004-2006, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.server;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.tools.beluga.ldap.messages.AddRequest;
import org.pfsw.tools.beluga.ldap.messages.AddResponse;
import org.pfsw.tools.beluga.ldap.messages.BindRequest;
import org.pfsw.tools.beluga.ldap.messages.BindResponse;
import org.pfsw.tools.beluga.ldap.messages.DeleteRequest;
import org.pfsw.tools.beluga.ldap.messages.DeleteResponse;
import org.pfsw.tools.beluga.ldap.messages.ModifyRequest;
import org.pfsw.tools.beluga.ldap.messages.ModifyResponse;
import org.pfsw.tools.beluga.ldap.messages.SearchRequest;
import org.pfsw.tools.beluga.ldap.messages.SearchResponse;
import org.pfsw.tools.beluga.ldap.messages.UnbindRequest;

/**
 * Defines the methods a processor of LDAP requests must implement.
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
abstract public class LDAPv3RequestProcessor
{ 
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  
  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
	/**
	 * Executes a LDAPv3 BindRequest.
	 * Returns a bindResponse or null if it doesn't handle the request.
	 * 
	 * @param request The bind request message.
	 */
  public BindResponse bind( BindRequest request )
  {
  	return null ; // Not handled
  } // bind() 
  
  // -------------------------------------------------------------------------
  
	/**
	 * Executes a LDAPv3 SearchRequest.
	 * Returns an array of serach response objects or null if it doesn't 
	 * handle the request.
	 * 
	 * @param request The search request message.
	 */
  public SearchResponse[] search( SearchRequest request )
  {
  	return null ; // Not handled
  } // search() 
  
  // -------------------------------------------------------------------------
  
	/**
	 * Executes a LDAPv3 UnbindRequest.
	 * 
	 * @param request The unbind request message.
	 */
  public void unbind( UnbindRequest request )
  {
  	// Nothing to do here
  } // unbind() 
  
  // -------------------------------------------------------------------------
  
  /**
   * Executes a LDAPv3 DeleteRequest.
   * 
   * @param request The delete request message.
   */
  public DeleteResponse delete( DeleteRequest request )
  {
  	return null ; // Not handled
  } // delete() 
  
  // -------------------------------------------------------------------------
  
  /**
   * Executes a LDAPv3 AddRequest.
   * 
   * @param request The add request message.
   */
  public AddResponse add( AddRequest request )
  {
  	return null ; // Not handled
  } // add() 
  
  // -------------------------------------------------------------------------
  
  /**
   * Executes a LDAPv3 ModifyRequest.
   * 
   * @param request The modify request message.
   */
  public ModifyResponse modify( ModifyRequest request )
  {
  	return null ; // Not handled
  } // modify() 
  
  // -------------------------------------------------------------------------
  
} // class LDAPv3RequestProcessor 
