// ===========================================================================
// CONTENT  : CLASS Transaction
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 11/07/2004
// HISTORY  :
//  11/07/2004  mdu  CREATED
//
// Copyright (c) 2004, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.tools.beluga.ldap.server ;

// ===========================================================================
// IMPORTS
// ===========================================================================

import org.pfsw.tools.beluga.common.LoggerService;
import org.pfsw.tools.beluga.ldap.messages.RequestMessage;
import org.pfsw.tools.beluga.ldap.messages.ResponseMessage;
import org.pfsw.tools.beluga.ldap.messages.SearchResponse;

/**
 * An instance of this class contains all objects that are necessary to
 * execute one requested LDAP transaction (e.g. bind, search).
 * That means it is a container for the request message, the response message(s)
 * and the comminication channel.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class Transaction
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private CommunicationChannel channel = null ;
  protected CommunicationChannel getChannel() { return channel ; }
  protected void setChannel( CommunicationChannel newValue ) { channel = newValue ; }
  
  private RequestMessage request = null ;
  protected RequestMessage getRequest() { return request ; }
  protected void setRequest( RequestMessage newValue ) { request = newValue ; }
  
  private ResponseMessage response = null ;
  protected ResponseMessage getResponse() { return response ; }
  protected void setResponse( ResponseMessage newValue ) { response = newValue ; }
  
  private SearchResponse[] searchResult = null ;
  public SearchResponse[] getSearchResult() { return searchResult ; }
  public void setSearchResult( SearchResponse[] newValue ) { searchResult = newValue ; }  
  // =========================================================================
  // CLASS METHODS
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with a communication channel.
   * 
   * @param commChannel The channel to communicate with the client
   */
  public Transaction( CommunicationChannel commChannel )
  {
    super() ;
    this.setChannel( commChannel ) ;
  } // Transaction() 
  
  // -------------------------------------------------------------------------

  /**
   * Initialize the new instance with a communication channel.
   * 
   * @param commChannel The channel to communicate with the client
   * @param request The request from the client to be processed in this transaction
   */
  public Transaction( CommunicationChannel commChannel, RequestMessage request )
  {
    this( commChannel ) ;
    this.setRequest( request ) ;
  } // Transaction() 
  
  // -------------------------------------------------------------------------

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected boolean hasSingleResponse() 
	{
		return this.getResponse() != null ;
	} // hasSingleResponse() 

	// -------------------------------------------------------------------------
  
  protected boolean hasSearchResult() 
	{
		return this.getSearchResult() != null ;
	} // hasSearchResult() 

	// -------------------------------------------------------------------------
  
	protected LoggerService logger() 
	{
		return LoggerService.getLogger() ;
	} // logger() 

	// -------------------------------------------------------------------------
	
} // class Transaction 
